@@ -1,7 +1,8 @@
 package WebService::GData::Node::APP;
-
+use WebService::GData::Constants qw/:namespace/;
 use WebService::GData::Node;
 
+
 sub import {
     my $package = caller;
     return if($package->isa(__PACKAGE__)||$package eq 'main'||$package!~m/APP::/);
@@ -12,7 +13,8 @@ sub import {
 }
 }
 
-sub root_name {'app'};
 
+sub namespace_prefix {APP_NAMESPACE_PREFIX}
+sub namespace_uri {APP_NAMESPACE_URI}
 
 1;
\ No newline at end of file
