@@ -1,5 +1,5 @@
 package WebService::GData::YouTube::YT::Derived;
-use WebService::GData::YouTube::Node;
+use WebService::GData::YouTube::YT;
 
 
 1;
\ No newline at end of file
